pysyte
=======

Python modules often used from dotfiles

Latest PyPi Package
-------------------

.. image:: https://badge.fury.io/py/pysyte.svg
   :target: https://pypi.python.org/pypi/pysyte
   :alt: PyPi Package

Build status
------------

.. image:: https://travis-ci.org/jalanb/pysyte.svg?branch=master
   :target: https://travis-ci.org/jalanb/pysyte
   :alt: Build Status

Test Coverage
-------------

.. image:: https://codecov.io/gh/jalanb/pysyte/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/jalanb/pysyte
   :alt: Test Coverage

Dependency status
-----------------

.. image:: https://caniusepython3.com/check/e81a8847-131d-4893-a47e-d4bd04e8817e.svg
    :target: https://caniusepython3.com/check/e81a8847-131d-4893-a47e-d4bd04e8817e
    :alt: Python 3 Status
